Changelog
---------
0.0.38 (2019-02-27)
~~~~~~~~~~~~~~~~~~~

- Adds a fulltext search hint.
  [msom]

0.0.37 (2019-02-27)
~~~~~~~~~~~~~~~~~~~

- Adds BFS maps.
  [msom]

0.0.36 (2019-02-27)
~~~~~~~~~~~~~~~~~~~

- Adds results by domain attachments.
  [msom]

0.0.35 (2019-02-25)
~~~~~~~~~~~~~~~~~~~

- Adds additional association recommendations.
  [msom]

0.0.34 (2019-02-25)
~~~~~~~~~~~~~~~~~~~

- Uses a single JSON column for all recommendations.
  [msom]

- Renames party recommendation dataset columns.
  [msom]

- Increases the maximum size of attachments to 50 MB.
  [msom]

0.0.33 (2019-02-20)
~~~~~~~~~~~~~~~~~~~

- Allows to add attachments to pages.
  [msom]

0.0.32 (2019-02-19)
~~~~~~~~~~~~~~~~~~~

- Shows party's recommendations in the strengths view.
  [msom]

- Adds datetime picker.
  [msom]

- Allows to sort votes by turnout.
  [msom]

0.0.31 (2019-02-14)
~~~~~~~~~~~~~~~~~~~

- Adds ad analysis.
  [msom]

- Caches the datasets.
  [msom]

0.0.30 (2019-02-10)
~~~~~~~~~~~~~~~~~~~

- Allows to add and remove content pages.
  [msom]

- Adds a static data protection content page.
  [msom]

- Removes the login link.
  [msom]

- Always display the number of cantons voted yeas/nays.
  [msom]

- Opens external links and files in a new window/tab.
  [msom]

- Hides empty rows in the detail view.
  [msom]

0.0.29 (2019-01-16)
~~~~~~~~~~~~~~~~~~~

- Adds cantonal results.
  [msom]

- Fixes formatting of procedure numbers.
  [msom]

0.0.28 (2019-01-09)
~~~~~~~~~~~~~~~~~~~

- Adds a bar chart with the percentages of the positions and results.
  [msom]

0.0.27 (2019-01-08)
~~~~~~~~~~~~~~~~~~~

- Adds a pagination to the vote details view.
  [msom]

- Adjusts styles to look more like anneepolitique.swiss.
  [msom]

0.0.26 (2018-12-18)
~~~~~~~~~~~~~~~~~~~

- Shows the localized file of the default locale if none is available for the
  current locale.
  [msom]

0.0.25 (2018-12-17)
~~~~~~~~~~~~~~~~~~~

- Adds the swissvotes logo.
  [msom]

0.0.24 (2018-12-17)
~~~~~~~~~~~~~~~~~~~

- Fixes default sorting of votes collections.
  [msom]

- Fixes display of the voter share of yes camp.
  [msom]

- Fixes display of procedure number.
  [msom]

0.0.23 (2018-12-11)
~~~~~~~~~~~~~~~~~~~

- Visually aligns the multiple tree select widget options.
  [msom]

0.0.21 (2018-12-11)
~~~~~~~~~~~~~~~~~~~

- Adds more margins to the multiple tree select widget.
  [msom]

0.0.20 (2018-12-11)
~~~~~~~~~~~~~~~~~~~

- Uses a multiple tree select widget for policy descriptors.
  [msom]

0.0.19 (2018-12-10)
~~~~~~~~~~~~~~~~~~~

- Adds descriptors.
  [msom]

- Fixes the click area of collapsible tables.
  [msom]

0.0.18 (2018-12-09)
~~~~~~~~~~~~~~~~~~~

- Import data files in alphabetical order.
  [msom]

- Fixes XLSX import for quasi-empty string cells.
  [msom]

0.0.17 (2018-12-09)
~~~~~~~~~~~~~~~~~~~

- Fixes data import.
  [msom]

0.0.16 (2018-12-09)
~~~~~~~~~~~~~~~~~~~

- Reorganizes the vote details view.
  [msom]

- Makes groups of vote details collapsible.
  [msom]

0.0.15 (2018-11-25)
~~~~~~~~~~~~~~~~~~~

- Fixes switching the extended filters.
  [msom]

0.0.14 (2018-11-21)
~~~~~~~~~~~~~~~~~~~

- Fixes displaying yeas and nays of council positions.
  [msom]

0.0.13 (2018-11-21)
~~~~~~~~~~~~~~~~~~~

- Improves the XLSX import.
  [msom]

0.0.12 (2018-11-20)
~~~~~~~~~~~~~~~~~~~

- Allows to search for BFS and procedure numbers.
  [msom]

- Allows to search by council positions.
  [msom]

- Adds a full text search option.
  [msom]

- Fixes the formatting of BFS numbers.
  [msom]

0.0.11 (2018-11-05)
~~~~~~~~~~~~~~~~~~~

- Adds resolution and realization attachments.
  [msom]

- Reorders the votes columns.
  [msom]

- Only shows the top level of the descriptor in the votes view.
  [msom]

- Uses the latest onegov.form.
  [msom]

0.0.10 (2018-10-07)
~~~~~~~~~~~~~~~~~~~

- Use tsquery phrases for multipley fulltext terms.
  [msom]

0.0.9 (2018-10-07)
~~~~~~~~~~~~~~~~~~~

- Uses prostgres for keyword filtering instead of elastic search.
  [msom]

0.0.8 (2018-09-28)
~~~~~~~~~~~~~~~~~~~

- Use a wider range of MIME types when updating the dataset.
  [msom]

0.0.7 (2018-09-28)
~~~~~~~~~~~~~~~~~~~

- Adds full text search support for attachments.
  [msom]

- Adds voting booklet attachments.
  [msom]

- Adds a CLI command for importing attachments.
  [msom]

- Makes the update, export and delete vote views to be indifferent to the filters.
  [msom]

- Handles search beeing unavailable.
  [msom]

- Sorts full text search results by rank.
  [msom]

0.0.6 (2018-09-23)
~~~~~~~~~~~~~~~~~~~

- Adds search.
  [msom]

- Uses XLSX for import.
  [msom]

- Uses excel format for CSV export.
  [msom]

0.0.5 (2018-09-18)
~~~~~~~~~~~~~~~~~~~

- Adds XLSX export.
  [msom]

- Improves UI.
  [msom]

- Enables English.
  [msom]

0.0.4 (2018-09-03)
~~~~~~~~~~~~~~~~~~~

- Styles content pages.
  [msom]

0.0.3 (2018-08-31)
~~~~~~~~~~~~~~~~~~~

- Improves vote(s) views.
  [msom]

- Adds editor options.
  [msom]

- Fixes votes pagination.
  [msom]

0.0.2 (2018-08-31)
~~~~~~~~~~~~~~~~~~~

- Adds the GitHub deploy key.
  [msom]

0.0.1 (2018-08-30)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [msom]
